==> IPLock-0.3.4.tar.gz: IPLock-0.3.4/lang/fr_FR.php <==
<?php 

$lang['postinstall'] = "L'installation d'IPLock est un succès";
$lang['manage'] = "Gestion d'IPLock";
$lang['preuninstall'] = 'La liste des IP autorisée sera détruite. Êtes-vous sur de vouloir désinstaller IPLock ?';
$lang['postuninstall'] = 'La désinstallation d\'IPLock est un succès';
$lang['moddescription'] = 'Ce module permet de gérer la liste des IP autorisées à se connecter sur l\'interface administrateur du site.';
$lang['installed'] = 'Module version %s installé';
$lang['uninstalled'] = 'Module version %s désinstallé';
$lang['help'] = <<<EOL
<h3>IPLock</h3>
<p>IPLock a pour vocation de filtrer les adresses IP ayant le droit de se connecter
à l'interface admin de CMS Made Simple.</p>
<p>Bien sûr, IPLock, dans cette version actuelle, n'est pas encore fonctionnel.</p>
<p>Une fois IPLock installé, il est nécessaire de modifier le fichier login.php situé dans le dossier
admin, afin que le travail soit fait correctement.</p>
EOL;
$lang['accessdenied'] = <<<AOL
<h3>Accès refusé</h3>
<p>Êtes vous sûr de posséder les droits suffisant ? Si oui, contactez votre administrateur afin
qu'il corrige le problème</p>
AOL;
$lang['genericerror'] = <<<UAL
Hohoho. Il semblerai que votre dernière opération ai généré une erreur. Êtes vous sûrs d'avoir tout fait correctement ?
UAL;
$lang['iperror'] = <<<AOL
L'IP spécifiée n'est pas valide.
AOL;
$lang['delete'] = 'Supprimer';
$lang['deleteconfirm'] = 'Confirmez la suppression';
$lang['emptylist'] = 'La liste est vide';
$lang['wrongip'] = '%s : IP non autorisée';
$lang['add'] = 'Ajouter';
$lang['added_allowed_ip'] = '%s : IP autorisée';
$lang['added_denied_ip'] = '%s : IP bannie';
$lang['removed_ip'] = '%s : IP supprimée';
$lang['prefs'] = 'Préférences';
$lang['allowed_ip'] = 'IPs autorisées';
$lang['denied_ip'] = 'IPs bannies';
$lang['save'] = 'Enregistrer les modifications';
?>

==> IPLock-0.3.5.tar.gz: IPLock-0.3.5/lang/fr_FR.php <==
<?php 

$lang['friendlyname'] = 'Blocage d\'IP';
$lang['postinstall'] = "L'installation d'IPLock est un succès";
$lang['manage'] = "Gestion d'IPLock";
$lang['preuninstall'] = 'La liste des IP autorisée sera détruite. Êtes-vous sur de vouloir désinstaller IPLock ?';
$lang['postuninstall'] = 'La désinstallation d\'IPLock est un succès';
$lang['moddescription'] = 'Ce module permet de gérer la liste des IP autorisées à se connecter sur l\'interface administrateur du site.';
$lang['installed'] = 'Module version %s installé';
$lang['uninstalled'] = 'Module version %s désinstallé';
$lang['help'] = <<<EOL
<h3>IPLock</h3>
<p>IPLock a pour vocation de filtrer les adresses IP ayant le droit de se connecter
à l'interface admin de CMS Made Simple.</p>
<p>Bien sûr, IPLock, dans cette version actuelle, n'est pas encore fonctionnel.</p>
<p>Une fois IPLock installé, il est nécessaire de modifier le fichier login.php situé dans le dossier
admin, afin que le travail soit fait correctement.</p>
EOL;
$lang['accessdenied'] = <<<AOL
<h3>Accès refusé</h3>
<p>Êtes vous sûr de posséder les droits suffisant ? Si oui, contactez votre administrateur afin
qu'il corrige le problème</p>
AOL;
$lang['genericerror'] = <<<UAL
Hohoho. Il semblerai que votre dernière opération ai généré une erreur. Êtes vous sûrs d'avoir tout fait correctement ?
UAL;
$lang['iperror'] = <<<AOL
L'IP spécifiée n'est pas valide.
AOL;
$lang['delete'] = 'Supprimer';
$lang['deleteconfirm'] = 'Confirmez la suppression';
$lang['emptylist'] = 'La liste est vide';
$lang['wrongip'] = '%s : IP non autorisée';
$lang['add'] = 'Ajouter';
$lang['added_allowed_ip'] = '%s : IP autorisée';
$lang['added_denied_ip'] = '%s : IP bannie';
$lang['removed_ip'] = '%s : IP supprimée';
$lang['prefs'] = 'Préférences';
$lang['allowed_ip'] = 'IPs autorisées';
$lang['denied_ip'] = 'IPs bannies';
$lang['allow_all'] = 'Autoriser à tous';
$lang['deny_all'] = 'Interdire à tous';
$lang['save'] = 'Enregistrer les modifications';
$lang['adminpanel_template'] = 'adminpanel_fr.tpl';
?>
